import shiffman.box2d.*;
import org.jbox2d.collision.shapes.*;
import org.jbox2d.common.*;
import org.jbox2d.dynamics.*;
import org.jbox2d.dynamics.contacts.*;
import processing.sound.*;

// A reference to our box2d world
Box2DProcessing box2d;

// Movers, jsut like before!
Ball[] ball = new Ball[10];

Boundary[] wall = new Boundary[4];

SoundFile soundfile;

void setup() {
  size(640, 360);
  smooth();

  box2d = new Box2DProcessing(this);
  box2d.createWorld();
  box2d.setGravity(0, -10);
  box2d.listenForCollisions();
  soundfile = new SoundFile(this, "ball.wav");

  for (int i = 0; i < ball.length; i++) {
    ball[i] = new Ball(random(0.01, 10), random(width), random(height));
  }
  wall[0] = new Boundary(width/2, height, width, 1);
  wall[1] = new Boundary(width/2, 0, width, 1);
  wall[2] = new Boundary(0, height/2, 1, height);
  wall[3] = new Boundary(width, height/2, 1, height);
}

void draw() {
  background(255);
  box2d.setGravity((mouseX-width/2)*0.05, (height/2-mouseY)*0.05);
  box2d.step();
  for (int i = 0; i < ball.length; i++) {
    ball[i].display();
  }
  for ( int i = 0; i < wall.length; i++ ) {
    wall[i].display();
  }
}

void beginContact(Contact cp)
{
   // Get both fixtures
  Fixture f1 = cp.getFixtureA();
  Fixture f2 = cp.getFixtureB();
  // Get both bodies
  Body b1 = f1.getBody();
  Body b2 = f2.getBody();

  // Get our objects that reference these bodies
  Object o1 = b1.getUserData();
  Object o2 = b2.getUserData();
  
  Vec2 v1 = b1.getLinearVelocity();
  Vec2 v2 = b2.getLinearVelocity();
  
  float V1 = sqrt(v1.x*v1.x+v1.y*v1.y);
  float V2 = sqrt(v2.x*v2.x+v2.y*v2.y);
  println(V1+V2);
  float volume = (V1+V2)/50.0;
  soundfile.play(volume, volume);
}
void endContact(Contact cp)
{
}